==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/pl_pl/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.pl_pl
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.edit.text_add'] = 'Dodaj';
$lang['AdminDepartments.edit.text_delete'] = 'Usuń';
$lang['AdminDepartments.edit.heading_default'] = 'Domyślny';
$lang['AdminDepartments.edit.heading_value'] = 'Wartość';
$lang['AdminDepartments.edit.heading_name'] = 'Nazwa';
$lang['AdminDepartments.edit.heading_options'] = 'Opcje';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Automatyczne usuwanie';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Szyfrowanie';
$lang['AdminDepartments.edit.heading_client_add'] = 'Klient może dodać';
$lang['AdminDepartments.edit.heading_step'] = 'Krok';
$lang['AdminDepartments.edit.heading_max'] = 'Max';
$lang['AdminDepartments.edit.heading_min'] = 'Min';
$lang['AdminDepartments.edit.heading_type'] = 'Typ';
$lang['AdminDepartments.edit.heading_visibility'] = 'Widoczność';
$lang['AdminDepartments.edit.heading_description'] = 'Opis';
$lang['AdminDepartments.edit.heading_label'] = 'Etykieta';
$lang['AdminDepartments.edit.no_results'] = 'W tym dziale nie ma pól niestandardowych.';
$lang['AdminDepartments.edit.confirm_field_remove'] = 'Czy na pewno chcesz usunąć to pole niestandardowe? Wszystkie dane powiązane z tym polem zostaną usunięte. Jeśli chcesz ukryć to pole i zachować dane, zmień jego widoczność na Tylko dla personelu.';
$lang['AdminDepartments.edit.field_add_field'] = 'Dodaj pole';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Dział edycji';
$lang['AdminDepartments.edit.field_status'] = 'Status';
$lang['AdminDepartments.edit.field_response_id'] = 'Automatyczne zamykanie odpowiedzi na bilet';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Wysyłanie przypomnień do biletów z priorytetem';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Wysyłanie przypomnień do biletów ze statusem';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Automatyczne wysyłanie przypomnień o biletach';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Automatyczne usuwanie biletów';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Automatyczne zamykanie zgłoszeń';
$lang['AdminDepartments.edit.field_port'] = 'Port';
$lang['AdminDepartments.edit.field_pass'] = 'Przełęcz';
$lang['AdminDepartments.edit.field_user'] = 'Użytkownik';
$lang['AdminDepartments.edit.field_host'] = 'Gospodarz';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Oznacz wiadomości jako';
$lang['AdminDepartments.edit.field_box_name'] = 'Nazwa pudełka';
$lang['AdminDepartments.edit.field_security'] = 'Bezpieczeństwo';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Maksymalny rozmiar załącznika';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Obsługiwane typy załączników';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Dołączanie obsługiwanych załączników do powiadomień o biletach';
$lang['AdminDepartments.edit.field_default_priority'] = 'Domyślny priorytet';
$lang['AdminDepartments.edit.field_piping_config'] = 'Konfiguracja rurociągów';
$lang['AdminDepartments.edit.field_method'] = 'Obsługa wiadomości e-mail';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Automatyczna zmiana statusu zgłoszenia po odpowiedzi administratora';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Wysyłaj wiadomości e-mail z automatyczną odpowiedzią na nowe bilety';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Zastąpienie adresu od ustawionego w szablonach wiadomości e-mail adresem e-mail ustawionym dla tego działu.';
$lang['AdminDepartments.edit.field_email'] = 'E-mail';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Wymagaj weryfikacji przez człowieka dla nieuwierzytelnionych użytkowników';
$lang['AdminDepartments.edit.field_clients_only'] = 'Zezwalaj tylko klientom na otwieranie lub odpowiadanie na zgłoszenia';
$lang['AdminDepartments.edit.field_description'] = 'Opis';
$lang['AdminDepartments.edit.field_name'] = 'Nazwa';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Pola niestandardowe';
$lang['AdminDepartments.edit.tab_general'] = 'Ogólne';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Dział edycji';
$lang['AdminDepartments.add.text_add'] = 'Dodaj';
$lang['AdminDepartments.add.text_delete'] = 'Usuń';
$lang['AdminDepartments.add.heading_default'] = 'Domyślne';
$lang['AdminDepartments.add.heading_value'] = 'Wartość';
$lang['AdminDepartments.add.heading_name'] = 'Nazwa';
$lang['AdminDepartments.add.heading_options'] = 'Opcje';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Automatyczne usuwanie';
$lang['AdminDepartments.add.heading_encrypted'] = 'Szyfrowanie';
$lang['AdminDepartments.add.heading_client_add'] = 'Klient może dodać';
$lang['AdminDepartments.add.heading_step'] = 'Krok';
$lang['AdminDepartments.add.heading_max'] = 'Max';
$lang['AdminDepartments.add.heading_min'] = 'Min';
$lang['AdminDepartments.add.heading_type'] = 'Typ';
$lang['AdminDepartments.add.heading_visibility'] = 'Widoczność';
$lang['AdminDepartments.add.heading_description'] = 'Opis';
$lang['AdminDepartments.add.heading_label'] = 'Etykieta';
$lang['AdminDepartments.add.field_add_field'] = 'Dodaj pole';
$lang['AdminDepartments.add.field_addsubmit'] = 'Dodaj dział';
$lang['AdminDepartments.add.field_status'] = 'Status';
$lang['AdminDepartments.add.field_response_id'] = 'Automatyczne zamykanie odpowiedzi na bilet';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Wysyłanie przypomnień do biletów z priorytetem';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Wysyłanie przypomnień do biletów ze statusem';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Automatyczne wysyłanie przypomnień o biletach';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Automatyczne usuwanie biletów';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Automatyczne zamykanie zgłoszeń';
$lang['AdminDepartments.add.field_port'] = 'Port';
$lang['AdminDepartments.add.field_pass'] = 'Przełęcz';
$lang['AdminDepartments.add.field_user'] = 'Użytkownik';
$lang['AdminDepartments.add.field_host'] = 'Gospodarz';
$lang['AdminDepartments.add.field_mark_messages'] = 'Oznacz wiadomości jako';
$lang['AdminDepartments.add.field_box_name'] = 'Nazwa pudełka';
$lang['AdminDepartments.add.field_security'] = 'Bezpieczeństwo';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Maksymalny rozmiar załącznika';
$lang['AdminDepartments.add.field_attachment_types'] = 'Obsługiwane typy załączników';
$lang['AdminDepartments.add.field_include_attachments'] = 'Dołączanie obsługiwanych załączników do powiadomień o biletach';
$lang['AdminDepartments.add.field_default_priority'] = 'Domyślny priorytet';
$lang['AdminDepartments.add.field_piping_config'] = 'Konfiguracja rurociągów';
$lang['AdminDepartments.add.field_method'] = 'Obsługa wiadomości e-mail';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Automatyczna zmiana statusu zgłoszenia po odpowiedzi administratora';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Wysyłaj wiadomości e-mail z automatyczną odpowiedzią na nowe bilety';
$lang['AdminDepartments.add.field_override_from_email'] = 'Zastąpienie adresu od ustawionego w szablonach wiadomości e-mail adresem e-mail ustawionym dla tego działu.';
$lang['AdminDepartments.add.field_email'] = 'E-mail';
$lang['AdminDepartments.add.field_require_captcha'] = 'Wymagaj weryfikacji przez człowieka dla nieuwierzytelnionych użytkowników';
$lang['AdminDepartments.add.field_clients_only'] = 'Zezwalaj tylko klientom na otwieranie lub odpowiadanie na zgłoszenia';
$lang['AdminDepartments.add.field_description'] = 'Opis';
$lang['AdminDepartments.add.field_name'] = 'Nazwa';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Pola niestandardowe';
$lang['AdminDepartments.add.tab_general'] = 'Ogólne';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Dodaj dział';
$lang['AdminDepartments.!text.remove_response'] = 'Usunąć';
$lang['AdminDepartments.!text.no_selected_response'] = 'Nie wybrano odpowiedzi automatycznego zamykania.';
$lang['AdminDepartments.!text.add_response'] = 'Ustaw wstępnie zdefiniowaną reakcję automatycznego zamykania';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Jeśli zgłoszenie zostanie zamknięte, dane pola zostaną automatycznie usunięte. Dane nie będą już widoczne dla pracowników.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Określa, czy klient może przesłać pole, jeśli nie, klient będzie mógł tylko odczytać pole.';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Maksymalny rozmiar załącznika w MB.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Lista obsługiwanych rozszerzeń oddzielonych przecinkiem (np. zip, jpg, png).';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Serwery pocztowe mają ograniczenia dotyczące rozmiarów załączników i typów plików. Aby zmniejszyć ryzyko odrzucenia wiadomości e-mail, należy uwzględnić ograniczenia dotyczące typu i rozmiaru załącznika. Aby upewnić się, że klient wie o załącznikach, które nie zostały dołączone, użyj tagu {ticket.reply_has_attachments} w powiadomieniach o biletach.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Zmienia status na %1$s, gdy członek personelu odpowie.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'Usunięcie zaznaczenia tego pola oznacza, że nowe bilety utworzone dla tego działu (przez e-mail lub klienta) nie będą wysyłać powiadomienia o odpowiedzi do klienta lub pracownika za pośrednictwem odpowiednio wiadomości e-mail z otrzymanym biletem lub wiadomości e-mail z aktualizacją biletu pracownika.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'W przypadku wszystkich biletów o statusie innym niż %1$s, przypomnienie zostanie wysłane do drugiej części, jeśli nie udzielono odpowiedzi w wybranym czasie.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Wszystkie bilety o statusie %1$s zostaną automatycznie usunięte, jeśli pozostaną w tym statusie przez wybrany czas.';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Wszystkie zgłoszenia o statusie innym niż %1$s, których ostatnia odpowiedź pochodzi od członka personelu, zostaną automatycznie zamknięte, jeśli w wybranym czasie nie zostanie udzielona żadna odpowiedź.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Ustaw ścieżkę pipingu jak pokazano, ale upewnij się, że używasz poprawnej ścieżki do PHP na swoim serwerze. Upewnij się, że pipe.php jest wykonywalny. Może być również konieczna edycja pliku pipe.php, aby zawierał hashbang w linii 1, który wyglądałby mniej więcej tak: #!/usr/bin/php';
$lang['AdminDepartments.assigned_staff.no_results'] = 'Do tego działu nie są przypisani żadni pracownicy.';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Personel';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Przydzielony personel';
$lang['AdminDepartments.index.no_results'] = 'Nie ma żadnych działów.';
$lang['AdminDepartments.index.confirm_delete'] = 'Działy z przypisanymi do nich biletami nie mogą zostać usunięte, dopóki wszystkie bilety nie zostaną ponownie przypisane do innego działu. Czy na pewno chcesz usunąć ten dział?';
$lang['AdminDepartments.index.option_delete'] = 'Usuń';
$lang['AdminDepartments.index.option_edit'] = 'Edytuj';
$lang['AdminDepartments.index.heading_options'] = 'Opcje';
$lang['AdminDepartments.index.heading_default_priority'] = 'Domyślny priorytet';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Przydzielony personel';
$lang['AdminDepartments.index.heading_email'] = 'E-mail';
$lang['AdminDepartments.index.heading_description'] = 'Opis';
$lang['AdminDepartments.index.heading_name'] = 'Nazwa';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Działy';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Dodaj dział';
$lang['AdminDepartments.edit.page_title'] = 'Menedżer wsparcia > Działy > Edytuj dział';
$lang['AdminDepartments.add.page_title'] = 'Menedżer wsparcia > Działy > Dodaj dział';
$lang['AdminDepartments.index.page_title'] = 'Menedżer wsparcia > Działy';
$lang['AdminDepartments.!success.department_deleted'] = 'Dział %1$s został pomyślnie usunięty.';
$lang['AdminDepartments.!success.department_updated'] = 'Dział %1$s został pomyślnie zaktualizowany.';
$lang['AdminDepartments.!success.department_created'] = 'Dział %1$s został pomyślnie utworzony.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/pl_pl/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.pl_pl
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.edit.text_add'] = 'Dodaj';
$lang['AdminDepartments.edit.text_delete'] = 'Usuń';
$lang['AdminDepartments.edit.heading_default'] = 'Domyślny';
$lang['AdminDepartments.edit.heading_value'] = 'Wartość';
$lang['AdminDepartments.edit.heading_name'] = 'Nazwa';
$lang['AdminDepartments.edit.heading_options'] = 'Opcje';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Automatyczne usuwanie';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Szyfrowanie';
$lang['AdminDepartments.edit.heading_client_add'] = 'Klient może dodać';
$lang['AdminDepartments.edit.heading_step'] = 'Krok';
$lang['AdminDepartments.edit.heading_max'] = 'Max';
$lang['AdminDepartments.edit.heading_min'] = 'Min';
$lang['AdminDepartments.edit.heading_type'] = 'Typ';
$lang['AdminDepartments.edit.heading_visibility'] = 'Widoczność';
$lang['AdminDepartments.edit.heading_description'] = 'Opis';
$lang['AdminDepartments.edit.heading_label'] = 'Etykieta';
$lang['AdminDepartments.edit.no_results'] = 'W tym dziale nie ma pól niestandardowych.';
$lang['AdminDepartments.edit.confirm_field_remove'] = 'Czy na pewno chcesz usunąć to pole niestandardowe? Wszystkie dane powiązane z tym polem zostaną usunięte. Jeśli chcesz ukryć to pole i zachować dane, zmień jego widoczność na Tylko dla personelu.';
$lang['AdminDepartments.edit.field_add_field'] = 'Dodaj pole';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Dział edycji';
$lang['AdminDepartments.edit.field_status'] = 'Status';
$lang['AdminDepartments.edit.field_response_id'] = 'Automatyczne zamykanie odpowiedzi na bilet';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Wysyłanie przypomnień do biletów z priorytetem';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Wysyłanie przypomnień do biletów ze statusem';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Automatyczne wysyłanie przypomnień o biletach';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Automatyczne usuwanie biletów';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Automatyczne zamykanie zgłoszeń';
$lang['AdminDepartments.edit.field_port'] = 'Port';
$lang['AdminDepartments.edit.field_pass'] = 'Przełęcz';
$lang['AdminDepartments.edit.field_user'] = 'Użytkownik';
$lang['AdminDepartments.edit.field_host'] = 'Gospodarz';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Oznacz wiadomości jako';
$lang['AdminDepartments.edit.field_box_name'] = 'Nazwa pudełka';
$lang['AdminDepartments.edit.field_security'] = 'Bezpieczeństwo';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Maksymalny rozmiar załącznika';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Obsługiwane typy załączników';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Dołączanie obsługiwanych załączników do powiadomień o biletach';
$lang['AdminDepartments.edit.field_default_priority'] = 'Domyślny priorytet';
$lang['AdminDepartments.edit.field_piping_config'] = 'Konfiguracja rurociągów';
$lang['AdminDepartments.edit.field_method'] = 'Obsługa wiadomości e-mail';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Automatyczna zmiana statusu zgłoszenia po odpowiedzi administratora';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Wysyłaj wiadomości e-mail z automatyczną odpowiedzią na nowe bilety';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Zastąpienie adresu od ustawionego w szablonach wiadomości e-mail adresem e-mail ustawionym dla tego działu.';
$lang['AdminDepartments.edit.field_email'] = 'E-mail';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Wymagaj weryfikacji przez człowieka dla nieuwierzytelnionych użytkowników';
$lang['AdminDepartments.edit.field_clients_only'] = 'Zezwalaj tylko klientom na otwieranie lub odpowiadanie na zgłoszenia';
$lang['AdminDepartments.edit.field_description'] = 'Opis';
$lang['AdminDepartments.edit.field_name'] = 'Nazwa';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Pola niestandardowe';
$lang['AdminDepartments.edit.tab_general'] = 'Ogólne';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Dział edycji';
$lang['AdminDepartments.add.text_add'] = 'Dodaj';
$lang['AdminDepartments.add.text_delete'] = 'Usuń';
$lang['AdminDepartments.add.heading_default'] = 'Domyślne';
$lang['AdminDepartments.add.heading_value'] = 'Wartość';
$lang['AdminDepartments.add.heading_name'] = 'Nazwa';
$lang['AdminDepartments.add.heading_options'] = 'Opcje';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Automatyczne usuwanie';
$lang['AdminDepartments.add.heading_encrypted'] = 'Szyfrowanie';
$lang['AdminDepartments.add.heading_client_add'] = 'Klient może dodać';
$lang['AdminDepartments.add.heading_step'] = 'Krok';
$lang['AdminDepartments.add.heading_max'] = 'Max';
$lang['AdminDepartments.add.heading_min'] = 'Min';
$lang['AdminDepartments.add.heading_type'] = 'Typ';
$lang['AdminDepartments.add.heading_visibility'] = 'Widoczność';
$lang['AdminDepartments.add.heading_description'] = 'Opis';
$lang['AdminDepartments.add.heading_label'] = 'Etykieta';
$lang['AdminDepartments.add.field_add_field'] = 'Dodaj pole';
$lang['AdminDepartments.add.field_addsubmit'] = 'Dodaj dział';
$lang['AdminDepartments.add.field_status'] = 'Status';
$lang['AdminDepartments.add.field_response_id'] = 'Automatyczne zamykanie odpowiedzi na bilet';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Wysyłanie przypomnień do biletów z priorytetem';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Wysyłanie przypomnień do biletów ze statusem';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Automatyczne wysyłanie przypomnień o biletach';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Automatyczne usuwanie biletów';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Automatyczne zamykanie zgłoszeń';
$lang['AdminDepartments.add.field_port'] = 'Port';
$lang['AdminDepartments.add.field_pass'] = 'Przełęcz';
$lang['AdminDepartments.add.field_user'] = 'Użytkownik';
$lang['AdminDepartments.add.field_host'] = 'Gospodarz';
$lang['AdminDepartments.add.field_mark_messages'] = 'Oznacz wiadomości jako';
$lang['AdminDepartments.add.field_box_name'] = 'Nazwa pudełka';
$lang['AdminDepartments.add.field_security'] = 'Bezpieczeństwo';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Maksymalny rozmiar załącznika';
$lang['AdminDepartments.add.field_attachment_types'] = 'Obsługiwane typy załączników';
$lang['AdminDepartments.add.field_include_attachments'] = 'Dołączanie obsługiwanych załączników do powiadomień o biletach';
$lang['AdminDepartments.add.field_default_priority'] = 'Domyślny priorytet';
$lang['AdminDepartments.add.field_piping_config'] = 'Konfiguracja rurociągów';
$lang['AdminDepartments.add.field_method'] = 'Obsługa wiadomości e-mail';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Automatyczna zmiana statusu zgłoszenia po odpowiedzi administratora';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Wysyłaj wiadomości e-mail z automatyczną odpowiedzią na nowe bilety';
$lang['AdminDepartments.add.field_override_from_email'] = 'Zastąpienie adresu od ustawionego w szablonach wiadomości e-mail adresem e-mail ustawionym dla tego działu.';
$lang['AdminDepartments.add.field_email'] = 'E-mail';
$lang['AdminDepartments.add.field_require_captcha'] = 'Wymagaj weryfikacji przez człowieka dla nieuwierzytelnionych użytkowników';
$lang['AdminDepartments.add.field_clients_only'] = 'Zezwalaj tylko klientom na otwieranie lub odpowiadanie na zgłoszenia';
$lang['AdminDepartments.add.field_description'] = 'Opis';
$lang['AdminDepartments.add.field_name'] = 'Nazwa';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Pola niestandardowe';
$lang['AdminDepartments.add.tab_general'] = 'Ogólne';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Dodaj dział';
$lang['AdminDepartments.!text.remove_response'] = 'Usunąć';
$lang['AdminDepartments.!text.no_selected_response'] = 'Nie wybrano odpowiedzi automatycznego zamykania.';
$lang['AdminDepartments.!text.add_response'] = 'Ustaw wstępnie zdefiniowaną reakcję automatycznego zamykania';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Jeśli zgłoszenie zostanie zamknięte, dane pola zostaną automatycznie usunięte. Dane nie będą już widoczne dla pracowników.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Określa, czy klient może przesłać pole, jeśli nie, klient będzie mógł tylko odczytać pole.';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Maksymalny rozmiar załącznika w MB.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Lista obsługiwanych rozszerzeń oddzielonych przecinkiem (np. zip, jpg, png).';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Serwery pocztowe mają ograniczenia dotyczące rozmiarów załączników i typów plików. Aby zmniejszyć ryzyko odrzucenia wiadomości e-mail, należy uwzględnić ograniczenia dotyczące typu i rozmiaru załącznika. Aby upewnić się, że klient wie o załącznikach, które nie zostały dołączone, użyj tagu {ticket.reply_has_attachments} w powiadomieniach o biletach.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Zmienia status na %1$s, gdy członek personelu odpowie.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'Usunięcie zaznaczenia tego pola oznacza, że nowe bilety utworzone dla tego działu (przez e-mail lub klienta) nie będą wysyłać powiadomienia o odpowiedzi do klienta lub pracownika za pośrednictwem odpowiednio wiadomości e-mail z otrzymanym biletem lub wiadomości e-mail z aktualizacją biletu pracownika.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'W przypadku wszystkich biletów o statusie innym niż %1$s, przypomnienie zostanie wysłane do drugiej części, jeśli nie udzielono odpowiedzi w wybranym czasie.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Wszystkie bilety o statusie %1$s zostaną automatycznie usunięte, jeśli pozostaną w tym statusie przez wybrany czas.';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Wszystkie zgłoszenia o statusie innym niż %1$s, których ostatnia odpowiedź pochodzi od członka personelu, zostaną automatycznie zamknięte, jeśli w wybranym czasie nie zostanie udzielona żadna odpowiedź.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Ustaw ścieżkę pipingu jak pokazano, ale upewnij się, że używasz poprawnej ścieżki do PHP na swoim serwerze. Upewnij się, że pipe.php jest wykonywalny. Może być również konieczna edycja pliku pipe.php, aby zawierał hashbang w linii 1, który wyglądałby mniej więcej tak: #!/usr/bin/php';
$lang['AdminDepartments.assigned_staff.no_results'] = 'Do tego działu nie są przypisani żadni pracownicy.';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Personel';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Przydzielony personel';
$lang['AdminDepartments.index.no_results'] = 'Nie ma żadnych działów.';
$lang['AdminDepartments.index.confirm_delete'] = 'Działy z przypisanymi do nich biletami nie mogą zostać usunięte, dopóki wszystkie bilety nie zostaną ponownie przypisane do innego działu. Czy na pewno chcesz usunąć ten dział?';
$lang['AdminDepartments.index.option_delete'] = 'Usuń';
$lang['AdminDepartments.index.option_edit'] = 'Edytuj';
$lang['AdminDepartments.index.heading_options'] = 'Opcje';
$lang['AdminDepartments.index.heading_default_priority'] = 'Domyślny priorytet';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Przydzielony personel';
$lang['AdminDepartments.index.heading_email'] = 'E-mail';
$lang['AdminDepartments.index.heading_description'] = 'Opis';
$lang['AdminDepartments.index.heading_name'] = 'Nazwa';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Działy';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Dodaj dział';
$lang['AdminDepartments.edit.page_title'] = 'Menedżer wsparcia > Działy > Edytuj dział';
$lang['AdminDepartments.add.page_title'] = 'Menedżer wsparcia > Działy > Dodaj dział';
$lang['AdminDepartments.index.page_title'] = 'Menedżer wsparcia > Działy';
$lang['AdminDepartments.!success.department_deleted'] = 'Dział %1$s został pomyślnie usunięty.';
$lang['AdminDepartments.!success.department_updated'] = 'Dział %1$s został pomyślnie zaktualizowany.';
$lang['AdminDepartments.!success.department_created'] = 'Dział %1$s został pomyślnie utworzony.';
$lang['AdminDepartments.edit.field_priorities'] = 'Dostępne priorytety';
$lang['AdminDepartments.add.field_priorities'] = 'Dostępne priorytety';
$lang['AdminDepartments.edit.field_force_import'] = 'Force Import';
$lang['AdminDepartments.add.field_force_import'] = 'Force Import';
$lang['AdminDepartments.!success.department_imported'] = 'Dział %1$s został pomyślnie zaimportowany.';
